==> haskell-hls-call-hierarchy-plugin-2.1.0.0-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-CSogcWQuR1YHe3lDu8nHR8
key:                  hls-call-hierarchy-plugin-2.1.0.0-CSogcWQuR1YHe3lDu8nHR8
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  e0fe75389f2e2e7eedc67834a91bfa4d
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-CSogcWQuR1YHe3lDu8nHR8
depends:
    aeson-2.1.2.1-4ODQ1UQyjV4HqW8vjPOsEA base-4.17.2.1 containers-0.6.7
    extra-1.7.16-DQhMeKr0WjwFMe69BFFypt
    ghcide-2.1.0.0-LXULviUYvaFLQ1mAjeqxyE
    hiedb-0.4.3.0-GYof1DTvt4FAcGYRnOKONB
    hls-plugin-api-2.1.0.0-FERa3uvmsKp8t4KWkwZhAJ
    lens-5.3.1-9oQplfPnoWr2g52V8zm4go
    lsp-2.1.0.0-4iFghRw06ptLSNgM2FCpZ4
    sqlite-simple-0.4.19.0-FSwEOVixmO8Lgz3mSPxzAk text-2.0.2
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-call-hierarchy-plugin-2.1.0.0-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.1.0.0-1yaj38bPbvBJzVAKmYfYzx
key:                  hls-call-hierarchy-plugin-2.1.0.0-1yaj38bPbvBJzVAKmYfYzx
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  e7898cf6d307f433c9c376712f10afc6
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-call-hierarchy-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.1.0.0-1yaj38bPbvBJzVAKmYfYzx
depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r base-4.17.2.1 containers-0.6.7
    extra-1.7.16-DOwdXWfQN4O1hxxIx77WWM
    ghcide-2.1.0.0-LX1ERPDJe7n97VaSPyush4
    hiedb-0.4.3.0-PV4KcGdpeb9sx5Lrt97WS
    hls-plugin-api-2.1.0.0-9URxRV0rFoi7ggEJCfCOsB
    lens-5.3.1-6s7OGBiqW0t1WJAI91dKgc
    lsp-2.1.0.0-KLUMztUaLnzIKmGW0jGo29
    sqlite-simple-0.4.19.0-1RGcsD1mdSgIUeDX2QPFRH text-2.0.2
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
